@@ -14,8 +14,6 @@ import os
 import sys
 sys.path.insert(0, os.path.abspath('..'))
 
-from setup import cfg                                           # noqa: E402
-
 
 # -- Project information -----------------------------------------------------
 
@@ -24,7 +22,8 @@ copyright = '2020-2021, Antonio Valentino'
 author = 'Antonio Valentino'
 
 # The full version, including alpha/beta/rc tags
-release = cfg['version']
+import bpack
+release = bpack.__version__
 
 master_doc = 'index'
 
@@ -38,6 +37,7 @@ extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.doctest',
     'sphinx.ext.intersphinx',
+    'sphinx.ext.extlinks',
     'sphinx.ext.todo',
     'sphinx.ext.coverage',
     'sphinx.ext.ifconfig',
@@ -126,6 +126,12 @@ intersphinx_mapping = {
     'https://numpy.org/doc/stable/': None,
 }
 
+# -- Options for extlinks extension ------------------------------------------
+
+extlinks = {
+    'issue': ('https://github.com/avalentino/bpack/issues/%s', 'gh-'),
+}
+
 # -- Options for todo extension ----------------------------------------------
 
 # If true, `todo` and `todoList` produce output, else they produce nothing.
